@@ -50,6 +50,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     # add_host_prefix_to_media_url = True                                    # 是否返回文件的时候加上当前域名的prefix
 
     flat_dc_ls = False      # 是否展平为list然后返回. 只有在返回一个字段的时候才生效.
+    add_page_dc = True      # 是否增加`page_dc`
 
     def __new__(cls, *args, **kwargs):
         ret = super().__new__(cls, *args, **kwargs)
@@ -286,11 +287,6 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         按order_type_ls指定的字段排序
         """
         query_dc = self.get_request_data()
-        # order_type_ls = get_list(query_dc, key='order_type_ls') \
-        #     if get_list(query_dc, key='order_type_ls') else self.order_type_ls
-
-        # distinct_field_ls = get_list(query_dc, key='distinct_field_ls')\
-        #     if get_list(query_dc, key='distinct_field_ls') else self.distinct_field_ls
 
         order_type_ls = self.get_key_from_query_dc_or_self('order_type_ls', get_type='list')
         distinct_field_ls = self.get_key_from_query_dc_or_self('distinct_field_ls', get_type='list')
@@ -310,7 +306,9 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
         # region # --- `order_by`操作
         if not pure.convert_query_parameter_to_bool(order_type_ls):
-            order_type_ls = ['pk']
+            base_model = get_base_model(self.queryset)
+            ordering = base_model._meta.ordering
+            order_type_ls = ordering if ordering else ['pk']
 
         # 要注意进行distinct之后的排序
         if distinct_field_ls and distinct_field_ls not in ['__None__', ['__None__']]:
@@ -446,10 +444,14 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         if flat_dc_ls and data and len(data[0]) == 1:
             data = [list(i.values())[0] for i in data]
 
-        ret = {
-            'page_dc': page_dc,
-            'data': data,
-        }
+        add_page_dc = get_key_from_request_data_or_self_obj(self.get_request_data(), self, 'add_page_dc', get_type='bool')
+        if add_page_dc:
+            ret = {
+                'page_dc': page_dc,
+                'data': data,
+            }
+        else:
+            ret = data
         return ret
 
     def _conv_data_format(self, *args, **kwargs):
